@@ -55,7 +55,7 @@ class Lotus:
                       self._api_endpoint, self.settings.token))
             return False
 
-    def rand_sec(self, start=1, end=10):
+    def rand_sec(self, start=1, end=7):
         return random.randrange(start, end)
 
     def check_modify(self, symbol, sl):
@@ -104,7 +104,7 @@ class Lotus:
                                         print("Open market order long into open Signal. {} {} Contracts, Stoploss: {}".format(
                                             symbol, contracts, stoploss), flush=True)
                                         self.order.bracket_market_order(
-                                            symbol, contracts, stoploss)
+                                            symbol, contracts, stoploss, cp)
                         else:
                             if self.order.props[symbol]['qty'] < 0 or self.client.open_contracts(symbol) < 0:
                                 self.check_modify(symbol, stoploss)
@@ -122,7 +122,7 @@ class Lotus:
                             else:
                                 cp = self.client.last_current_price(symbol)
                                 if cp > entry:
-                                    sl_dist = abs(entry-cp)
+                                    sl_dist = abs(stoploss-cp)
                                     if sl_dist > 0.15 * sl_dist:
                                         time.sleep(2)
                                         contracts = self.order.calc_pos_size(
@@ -130,29 +130,23 @@ class Lotus:
                                         print("Open market order short into open Signal. {} {} Contracts, Stoploss: {}".format(
                                             symbol, contracts, stoploss), flush=True)
                                         self.order.bracket_market_order(
-                                            symbol, -contracts, stoploss)
+                                            symbol, -contracts, stoploss, cp)
                     elif signal in [-2, 2]:  # signal has pending order
                         if self.order.props[symbol]['wait_stop']:
                             print("Cancel old order {} first.".format(symbol))
                             self.order.stoporder_cancel(symbol)  # cancel old order first
                             time.sleep(3)
+                        elif self.order.props[symbol]['open']:
+                            print("Close old order {} first, because of new signal".format(symbol))
+                            self.order.close(symbol)  # cancel old order first
+                            time.sleep(3)
                         contracts = self.order.calc_pos_size(symbol, abs(entry - stoploss))
                         if signal == 2:
-                            if self.order.props[symbol]['qty'] < 0:
-                                print(
-                                    "Canceling stop order in other direction.", flush=True)
-                                self.order.stoporder_cancel(symbol)
-                                time.sleep(3)
                             print("Open bracket stop order long. {} {} Contracts, Entry: {}, Stoploss: {}".format(
                                 symbol, contracts, entry, stoploss), flush=True)
                             self.order.bracket_stop_order(
                                 symbol, contracts, entry, stoploss)
                         else:
-                            if self.order.props[symbol]['qty'] > 0:
-                                print(
-                                    "Canceling stop order in other direction.", flush=True)
-                                self.order.stoporder_cancel(symbol)
-                                time.sleep(3)
                             print("Open bracket stop order short. {} {} Contracts, Entry: {}, Stoploss: {}".format(
                                 symbol, contracts, entry, stoploss), flush=True)
                             self.order.bracket_stop_order(
@@ -169,7 +163,8 @@ class Lotus:
         while True:
             time.sleep(10)
             self.order.manage_entries(self.symbols)
-            if datetime.datetime.now().minute % 30 == 0:
-                time.sleep(19 + self.rand_sec(start=3))
+            if datetime.datetime.utcnow().minute % 30 == 0:
+                second = datetime.datetime.utcnow().second
+                time.sleep(second + 21 - second + self.rand_sec(start=2))
                 self.process_signals()
                 time.sleep(40)
